/*
       ierror.c
       GNU Licence

       author: Rafal Michniewicz 
        email: <rafim@data.pl>
       jabber: rafim@jabber.org
    home page: http://smbc.airm.net
*/
// -------------------------------------------------------------------
#include <stdio.h>

void 
err_dump(char *st)
{
  printf("%s\n", st);
}

void 
err_sys(char *st)
{
  printf("%s\n", st);
}
  
